SerialConfig

Struct SerialConfig 

pub struct SerialConfig {
    pub baud_rate: u32,
    pub data_bits: DataBits,
    pub parity: Parity,
    pub stop_bits: StopBits,
    pub flow_control: bool,
}
Serial port configuration.

Fields

baud_rate: u32

Baud rate (bits per second).

data_bits: DataBits

Data bits per character.

parity: Parity

Parity setting.

stop_bits: StopBits

Stop bits.

flow_control: bool

Enable hardware flow control (RTS/CTS).

Implementations

Source

impl SerialConfig

pub fn new(baud_rate: u32) -> Self

Create a new serial config with the given baud rate.

pub fn baud_9600() -> Self

Common configuration: 9600/8N1.

pub fn baud_19200() -> Self

Common configuration: 19200/8N1.

pub fn baud_38400() -> Self

Common configuration: 38400/8N1.

pub fn baud_115200() -> Self

Common configuration: 115200/8N1.

pub fn with_parity(self, parity: Parity) -> Self

Set parity.

pub fn with_stop_bits(self, stop_bits: StopBits) -> Self

Set stop bits.

pub fn with_data_bits(self, data_bits: DataBits) -> Self

Set data bits.

pub fn bits_per_character(&self) -> f32

Calculate bits per character (start + data + parity + stop).

pub fn char_time(&self) -> Duration

Calculate character transmission time.

pub fn transmission_time(&self, bytes: usize) -> Duration

Calculate transmission time for a given number of bytes.

pub fn inter_frame_timeout(&self) -> Duration

Calculate inter-frame timeout (3.5 character times).

pub fn inter_char_timeout(&self) -> Duration

Calculate inter-character timeout (1.5 character times).