ConfigUpdate

Enum ConfigUpdate 

pub enum ConfigUpdate {
Show 14 variants MaxConnections(usize), IdleTimeout(Duration), RequestTimeout(Duration), UnitEnabled { unit_id: u8, enabled: bool, }, TcpNoDelay(bool), KeepaliveInterval(Option<Duration>), RegisterReadAccess { unit_id: u8, start_address: u16, count: u16, allowed: bool, }, RegisterWriteAccess { unit_id: u8, start_address: u16, count: u16, allowed: bool, }, SetRegister { unit_id: u8, address: u16, value: u16, }, SetRegisters { unit_id: u8, start_address: u16, values: Vec<u16>, }, SetCoil { unit_id: u8, address: u16, value: bool, }, MetricsEnabled(bool), DebugLogging(bool), Custom { key: String, value: String, },
}
Dynamic configuration value that can be changed at runtime.

Variants



MaxConnections(usize)

Update maximum concurrent connections.



IdleTimeout(Duration)

Update connection idle timeout.



RequestTimeout(Duration)

Update request timeout.



UnitEnabled

Enable/disable a specific unit ID.

Fields

unit_id: u8
enabled: bool


TcpNoDelay(bool)

Update TCP nodelay setting.



KeepaliveInterval(Option<Duration>)

Update keepalive interval.



RegisterReadAccess

Update register read access for a range.

Fields

unit_id: u8
start_address: u16
count: u16
allowed: bool


RegisterWriteAccess

Update register write access for a range.

Fields

unit_id: u8
start_address: u16
count: u16
allowed: bool


SetRegister

Set a register value.

Fields

unit_id: u8
address: u16
value: u16


SetRegisters

Set multiple register values.

Fields

unit_id: u8
start_address: u16
values: Vec<u16>


SetCoil

Set a coil value.

Fields

unit_id: u8
address: u16
value: bool


MetricsEnabled(bool)

Enable/disable metrics collection.



DebugLogging(bool)

Enable/disable debug logging.



Custom

Custom extension for protocol-specific settings.

Fields

value: String

Implementations

Source

impl ConfigUpdate

pub fn category(&self) -> UpdateCategory

Get the category of this update.

pub fn requires_restart(&self) -> bool

Check if this update requires a restart to take effect.