CompiledModbusSession

Struct CompiledModbusSession 

pub struct CompiledModbusSession {
Show 21 fields pub session_name: String, pub launch: ProtocolLaunchSpec, pub transport_kind: CompiledTransportKind, pub profile: SimulatorProfile, pub trace: SessionTraceConfig, pub reset: SessionResetPolicy, pub control: SessionControlConfig, pub fault_presets: BTreeMap<String, FaultInjectionConfig>, pub active_fault_preset: Option<String>, pub response_profiles: BTreeMap<String, ResponseProfileDefinition>, pub active_response_profile: Option<String>, pub actions: BTreeMap<String, ActionDefinition>, pub behaviors: BTreeMap<String, BehaviorDefinition>, pub behavior_sets: BTreeMap<String, BehaviorSetDefinition>, pub active_behavior_set: Option<String>, pub point_catalog: BTreeMap<String, CompiledPointMetadata>, pub datastore_policies: Vec<DatastorePolicySummary>, pub action_binding_summaries: Vec<ActionBindingSummary>, pub behavior_binding_summaries: Vec<BehaviorBindingSummary>, pub compiled_behavior_bindings: Vec<CompiledBehaviorBinding>, pub readiness_timeout_ms: Option<u64>,
}
Compiled runtime-ready session.

Fields

session_name: Stringlaunch: ProtocolLaunchSpectransport_kind: CompiledTransportKindprofile: SimulatorProfiletrace: SessionTraceConfigreset: SessionResetPolicycontrol: SessionControlConfigfault_presets: BTreeMap<String, FaultInjectionConfig>active_fault_preset: Option<String>response_profiles: BTreeMap<String, ResponseProfileDefinition>active_response_profile: Option<String>actions: BTreeMap<String, ActionDefinition>behaviors: BTreeMap<String, BehaviorDefinition>behavior_sets: BTreeMap<String, BehaviorSetDefinition>active_behavior_set: Option<String>point_catalog: BTreeMap<String, CompiledPointMetadata>datastore_policies: Vec<DatastorePolicySummary>action_binding_summaries: Vec<ActionBindingSummary>behavior_binding_summaries: Vec<BehaviorBindingSummary>compiled_behavior_bindings: Vec<CompiledBehaviorBinding>readiness_timeout_ms: Option<u64>

Implementations

Source

impl CompiledModbusSession

pub fn runtime_extensions(&self) -> RuntimeExtensions

Returns the runtime extensions implied by the compiled session.

pub fn with_active_fault_preset( &self, preset: Option<&str>, ) -> ModbusResult<Self>

Returns a cloned session with a different active fault preset.

pub fn with_active_response_profile( &self, profile: Option<&str>, ) -> ModbusResult<Self>

Returns a cloned session with a different active response profile.

pub fn with_active_behavior_set( &self, behavior_set: Option<&str>, ) -> ModbusResult<Self>

Returns a cloned session with a different active behavior set.

pub fn active_fault_config(&self) -> Option<FaultInjectionConfig>

Returns the currently active fault injection config, if one exists.

pub fn active_response_profile_definition( &self, ) -> Option<ResponseProfileDefinition>

Returns the currently active response profile, if one exists.

pub fn active_runtime_fault_config(&self) -> Option<FaultInjectionConfig>

Returns the merged runtime fault config implied by fault presets and response profiles.

pub fn point_metadata( &self, device_id: &str, point_id: &str, ) -> Option<&CompiledPointMetadata>